/**
 * @(#) SelectionEvent.java
 */

package org.omg.tacsit.controller;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;

/**
 * {@linkplain SelectionEvent} is the type of event that is passed to a 
 * {@link SelectionListener} each time there is a change in one of the 
 * selections of a {@link SelectionManager}.
 */
public class SelectionEvent
{
	private SelectionManager source;
	
	private SelectionType type;
	
	private Collection<Entity> entities;
	
  /**
   * Constructs a new instance.
   * @param entities The {@link Entity} objects that are selected.
   * @param source The {@link SelectionManager} that event originated from.
   * @param type The {@link SelectionType} that defines which selection is represented.
   */
	public SelectionEvent(Collection<Entity> entities, SelectionManager source, SelectionType type )
	{
    if(entities == null)
    {
      this.entities = Collections.emptyList();
    }
    else
    {
      // Copy the list to ensure no external modifications are made to the event after its creation.
      List<Entity> listCopy = new ArrayList(entities);
      this.entities = Collections.unmodifiableList(listCopy);
    }
    this.source = source;
    this.type = type;
		
	}
	
  /**
   * Gets the {@link Entity} objects that have been selected.
   * <p>  The returned {@link Collection} is unmodifiable.
   * @return The {@link Entity} objects which have been selected.
   */
	public Collection<Entity> getEntities( )
	{
		return this.entities;
	}
	
	/**
	 * Gets the type of selection that has been changed.
	 * 
	 * @return the type of selection that has changed.
	 */
	public SelectionType getSelectionType( )
	{
		return this.type;
	}
	
	/**
	 * Gets the source where the event originated.
	 * 
	 * @return the SelectionManager in which the selection change occurred.
	 */
	public SelectionManager getSource( )
	{
		return this.source;
	}
	
}
