/**
 * @(#) TacsitController.java
 */

package org.omg.tacsit.controller;

import java.util.Collection;
import org.omg.tacsit.query.QueryManager;

/**
 * The top level interface for the Tactical Situation display (TacSit) Controller
 * interface, which enables clients to interact with Viewports and Query TacSit
 * content in terms of the Entity class.
 * <p>
 * The TacSit Controller interface does not provide the mechanism for adding
 * Entities to a TacSit. When a client receives an Entity from a Query, the
 * client of the TacSit controller will interpret the Entity according to
 * interfaces provided by other components than the Tacsit Controller (for
 * instance an interaction with another component, which is known to have added
 * the Entity to the TacSit by some other interface).
 */
public interface TacsitController
{
	/**
	 * Returns the projections which are supported by the TACSIT.
	 * <p>
   * Attempted changes to the collection returned by this method will have no 
   * effect on the behavior and functionality of the TacsitController.
	 * 
	 * @return The {@link Projection}s that are supported by this controller.
	 */
	Collection<Projection> getProjections( );
	
	/**
	 * Returns the Entity Types that are supported by the TAC SIT. This will 
   * return a list of all Entity Types available for Selection and Query by 
   * this TACSITController.
	 * <p>
   * Attempted changes to the collection returned by this method will have no 
   * effect on the behavior and functionality of the TacsitController.
	 * @return The {@link EntityType{s that are supported by this controller.
	 */
	Collection<EntityType> getEntityTypes( );
	
	/**
	 * Gets the {@link ViewportManager} for this {@linkplain TacsitController}.
	 * 
	 * @return the {@link ViewportManager} for this {@linkplain TacsitController}
	 */
	ViewportManager getViewportManager( );
	
	/**
	 * Gets the {@link QueryManager} for this {@linkplain TacsitController}.
	 * 
	 * @return the {@link QueryManager} for this {@linkplain TacsitController}
	 */
	QueryManager getQueryManager( );
	
	/**
	 * Gets the {@link SelectionMethodology} of the {@linkplain TacsitController}
	 * 
	 * @return the {@link SelectionMethodology} of the {@linkplain TacsitController}
	 */
	SelectionMethodology getSelectionMethodology( );
	
	/**
	 * Return the {@link SelectionManager} that handles the selection on the 
   * {@link Viewport} with name viewportName.
	 * <p>
	 * Depending on the {@link SelectionMethodology} of the 
   * {@linkplain TacsitController}, the returned {@link SelectionManager}s 
   * for multiple viewports will be identical or different.
	 * 
   * @param viewportName The name of the {@link Viewport} to get the
   * {@link SelectionManager} for.
	 * @return The {@link SelectionManager} for that {@link Viewport}.
	 */
	SelectionManager getSelectionManager( String viewportName );	
	
}
