/**
 * @(#) ViewEyeProperties.java
 */
package org.omg.tacsit.controller;

import org.omg.tacsit.geometry.Angle;
import org.omg.tacsit.geometry.Distance;
import org.omg.tacsit.geometry.GeodeticPosition;

/**
 * ViewEyeProperties groups the attributes of a ViewPort that have an impact on
 * the position where Entities are displayed in the Viewport.
 */
public class ViewEyeProperties
{

  /**
   * The GeoCenter of the {@link Viewport}.
   * <p>
   * The geoCenter of the {@linkplain Viewport} is the Geoposition that is 
   * displayed in the center of the {@linkplain Viewport} 
   * (i.e., on a {@linkplain Viewport} of w pixels wide and h pixels
   * high, it is displayed on pixel (w/2, h/2) ).
   */
  private GeodeticPosition geoCenter;
  
  /**
   * The range scale of the {@link Viewport}.
   * <p>
   * The range scale is the distance from the center of the viewport to the
   * nearest {@link Viewport} edge.
   */
  private Distance rangeScale;
  
  /**
   * The orientation of the {@link Viewport}.
   * <p>
   * The orientation is applied on the Viewport as a rotation of the Viewport
   * in clockwise direction around the Viewport's center.
   */
  private Angle orientation;
  /**
   * The projection of the {@link Viewport}.
   * <p>
   * The projection object here is assumed to be one of the options provided
   * by the high level TACSIT Controller method "getProjections()". This
   * standard does not address any further details of how to handle
   * projections.
   */
  private Projection projection;

  /**
   * Gets the GeoCenter of the {@linkplain ViewEyeProperties}.
   * <p>
   * The geoCenter is the Geoposition that is displayed in the center of the 
   * {@link Viewport} (i.e., on a {@link Viewport} of w pixels wide and 
   * h pixels high, it is displayed on pixel (w/2, h/2) ).
   * @return
   */
  public GeodeticPosition getGeoCenter()
  {
    return geoCenter;
  }

  /**
   * Gets the range scale of the {@linkplain ViewEyeProperties}.
   * @return The range scale from the center of the viewport to the
   * nearest {@link Viewport} edge.
   */
  public Distance getRangeScale()
  {
    return rangeScale;
  }

  /**
   * Gets the orientation of the  {@linkplain ViewEyeProperties}.
   * <p>
   * The orientation is applied on the {@linkplain Viewport} as a rotation of the {@linkplain Viewport}
   * in clockwise direction around the {@linkplain Viewport}'s center.
   * @return The orientation of the {@link Viewport}.
   */
  public Angle getOrientation()
  {
    return orientation;
  }

  /**
   * Gets the projection of the {@linkplain ViewEyeProperties}.
   * <p>
   * The projection object here is assumed to be one of the options provided
   * by the high level TACSIT Controller method "getProjections()". This
   * standard does not address any further details of how to handle
   * projections.
   * @return
   */
  public Projection getProjection()
  {
    return projection;
  }

  /**
   * Sets the projection of the {@linkplain ViewEyeProperties}.
   * <p>
   * The projection object here is assumed to be one of the options provided
   * by the high level TACSIT Controller method "getProjections()". This
   * standard does not address any further details of how to handle
   * projections.
   * @param projection The projection of the Viewport.
   */
  public void setProjection(Projection projection)
  {
    this.projection = projection;
  }

  /**
   * Sets the GeoCenter of the  {@linkplain ViewEyeProperties}.
   * <p>
   * The geoCenter of the Viewport is the Geodetic position that is displayed in the
   * center of the Viewport (i.e., on a Viewport of w pixels wide and h pixels
   * high, it is displayed on pixel (w/2, h/2) ).
   * @param geoCenter The geodetic center of the Viewport.
   */
  public void setGeoCenter(GeodeticPosition geoCenter)
  {
    this.geoCenter = geoCenter;
  }

  /**
   * Sets the range scale of the {@linkplain ViewEyeProperties}.
   * @param rangeScale The range scale from the center of the viewport to the
   * nearest {@link Viewport} edge.
   */
  public void setRangeScale(Distance rangeScale)
  {
    this.rangeScale = rangeScale;
  }


  /**
   * Sets the orientation of the {@link Viewport}.
   * <p>
   * The orientation is applied on the {@linkplain Viewport} as a rotation of the {@linkplain Viewport}
   * in clockwise direction around the {@linkplain Viewport}'s center.
   * @return The orientation of the {@link Viewport}.
   */
  public void setOrientation(Angle orientation)
  {
    this.orientation = orientation;
  }
}
