/**
 * @(#) ViewportChangeEvent.java
 */

package org.omg.tacsit.controller;

/**
 * ViewportChangeEvent is the type of event that is passed to a
 * ViewportChangeListener each time the Viewport changes.
 * <p>
 * Through the ViewportChangeEvent it is possible to know which Viewport has
 * been changed and details of the change.
 * <p>
 * If there are properties other than the view eye that the client is interested
 * in, they can query the associated Viewport Object contained in the event
 * available in the getSource() method.
 */
public class ViewportChangeEvent
{
	private final Viewport viewport;
	
	private final ViewEyeProperties viewEyeProperties;
	
  /**
   * Constructs a new instance.
   * @param viewport The source of the event.
   * @param viewEyeProperties The new view eye of the given {@link Viewport}.
   */
	public ViewportChangeEvent( Viewport viewport, ViewEyeProperties viewEyeProperties )
	{
		this.viewport = viewport;
    this.viewEyeProperties = viewEyeProperties;
	}
	
	/**
	 * Gets a copy of the ViewEyeProperties of the {@link Viewport} that has changed.
	 * 
	 * @return a copy of the ViewEyeProperties of the {@link Viewport} that has changed.
	 */
	public ViewEyeProperties getViewEyeProperties( )
	{
		return viewEyeProperties;
	}
	
	/**
	 * Gets the {@link Viewport} that has changed.
	 * 
	 * @return the {@link Viewport} that has changed
	 */
	public Viewport getSource( )
	{
		return viewport;
	}
	
}
