/**
 * @(#) ViewportManager.java
 */

package org.omg.tacsit.controller;

import java.util.Collection;

/**
 * The ViewportManager enables a TacSit client to manage Viewport instances and
 * track changes to the set of Viewports. Construction of a Viewport is outside
 * of the scope of this interface.
 */
public interface ViewportManager
{
	/**
	 * Gets all Viewports managed by this ViewportManager.  The collection returned by this method is unmodifiable.
	 * 
	 * @return all Viewports managed by this ViewportManager
	 */
	Collection<Viewport> getViewports( );
	
	/**
	 * Add a {@link Viewport} to this ViewportManager.
	 * <p>
	 * If the Viewport is already added to the ViewportManager before, this
	 * operation has no effect.
	 * 
   * @param viewport The {@link Viewport} to add to the manage.
	 */
	void addViewport( Viewport viewport );
	
	/**
	 * Remove the given {@link Viewport} from this ViewportManager.
	 * <p>
	 * If the given Viewport is not managed by this ViewportManager, this
	 * operation as no effect.
	 * 
   * @param viewport The {@link Viewport} that should no longer be managed.
	 */
	void removeViewport( Viewport viewport );
	
	/**
	 * Registers the given ViewportManagerListener to this ViewportManager.
	 * <p>
	 * After registration the ViewportManagerListener will be notified through
	 * each time that a viewport is added or removed through its corresponding
	 * method.
	 * <p>
	 * Registering a ViewportManagerListener that was already registered with
	 * this ViewportManager does not have any effect.
   * 
   * @param listener The listener that wants to receive notification about
   * changes to the {@linkplain ViewportManager}.
	 */
	void addViewportManagerListener( ViewportManagerListener listener );
	
	/**
	 * Unregisters the givenViewportManagerListener from this ViewportManager.
	 * <p>
	 * Afterwards the ViewportManagerListener will not be notified of added or
	 * removed Viewports.
	 * <p>
	 * Unregistering a ViewportManagerListener that was not registered does not
	 * have any effect.
   * 
   * @param listener The listener that no longer wants to receive notifications.
	 */
	void removeViewportManagerListener( ViewportManagerListener listener );
	
	/**
	 * Return the viewport with the given name.
	 * <p>
	 * If there is no such viewport, null is returned.
	 * 
   * @param name The name of the {@link Viewport} to retrieve.
	 * @return A {@link Viewport} that has the given name.
	 */
	Viewport getViewport( String name );	
	
}
