/**
 * @(#) ViewportManagerEvent.java
 */

package org.omg.tacsit.controller;

/**
 * ViewportManagerEvent is the type of event that is passed to a
 * ViewportManagerListener each time there is a Viewport is added or removed
 * from the ViewportManager.
 * 
 * Through the ViewportManagerEvent it is possible to know which Viewport has
 * been added to which ViewportManager
 */
public class ViewportManagerEvent
{
  private Viewport viewport;
  private ViewportManager source;

  /**
   * Constructs a new instance.
   * @param viewport The {@link Viewport} that has been added or removed. 
   * @param source The manager that originated the event.
   */
  public ViewportManagerEvent(Viewport viewport, ViewportManager source)
  {
    this.viewport = viewport;
    this.source = source;
  }

	/**
	 * Gets the {@link Viewport} that has been added or removed by this event.
	 * 
	 * @return the {@link Viewport} that has been added or removed by this event.
	 */
	public Viewport getViewport( )
  {
    return this.viewport;
  }
	
	/**
	 * Gets the ViewportManager to which a Viewport has been added or
	 * removed.
	 * 
	 * @return the ViewportManager to which a Viewport has been added or
	 * removed.
	 */
	ViewportManager getSource( )
  {
    return this.source;
  }
}
