/**
 * @(#) ViewportManagerListener.java
 */

package org.omg.tacsit.controller;

/**
 * ViewportManagerListener is the type of object that is notified by a
 * ViewportManager where it is registered in case a Viewport is added or removed
 * from that ViewportManager.
 */
public interface ViewportManagerListener
{
	/**
	 * This method is called by the ViewportManager where this
	 * ViewportManagerListener is registered in case a Viewport is added.
	 * <p>
	 * The details of the addition can be obtained through the given
	 * ViewportManagerEvent.
	 * 
   * @param event An event describing the Viewport that was added.
	 */
	void viewportAdded( ViewportManagerEvent event );
	
	/**
	 * This method is called by the ViewportManager where this
	 * ViewportManagerListener is registered in case a Viewport is removed.
	 * <p>
	 * The details of the removal can be obtained through the given
	 * ViewportManagerEvent.
	 * 
   * @param event An event describing the Viewport that was removed.
	 */
	void viewportRemoved( ViewportManagerEvent event );
	
	
}
