/**
 * @(#) Angle.java
 */
package org.omg.tacsit.geometry;

/**
 * The angular distance between two intersecting lines.
 * <p>
 * {@linkplain Angle} objects are immutable.  All methods that operate on the 
 * state of the {@linkplain Angle} do not modify its value.
 */
public interface Angle
{
  /**
   * Gets the value of this {@linkplain Angle} as expressed in degrees.
   * @return The degree value angular measurement.
   */
  double getDegrees();

  /**
   * Gets the value of this {@linkplain Angle}, as expressed in radians.
   * @return The radian value angular measurement.
   */
  double getRadians();

  /**
   * Returns a new {@linkplain Angle} which represents the sum of this 
   * angular distance and the parameter (this + that).
   * <p>
   * Neither this {@linkplain Angle} nor the parameter are modified.
   * @param angle The {@linkplain Angle} to add to this {@linkplain Angle}.
   * @return A new {@linkplain Angle} which represents (this + that).
   */
  Angle add(Angle angle);
  
  /**
   * Returns a new {@linkplain Angle} which represents the difference of this 
   * angular distance and the parameter (this - that).
   * <p>
   * Neither this angle nor the parameter are modified.
   * @param angle The {@linkplain Angle} to subtract from this {@linkplain Angle}.
   * @return A new {@linkplain Angle} which represents (this - that).
   */
  Angle subtract(Angle angle);
  
}
