/**
 * @(#) QueryManager.java
 */

package org.omg.tacsit.query;

import java.util.Collection;
import org.omg.tacsit.controller.Entity;

/**
 * The QueryManager supports the execution of queries for entities against the
 * TacSit Controller.
 * <p>
 * Queries submitted through the QueryManager are transient in nature; that is,
 * the results of a query represent the state of the TacSit Controller at the
 * time the Query was executed. Query results will not be maintained by the
 * QueryManager as the state of the TacSit Controller changes. Since the
 * QueryManager treats the Query objects as stateless, the same Query may be
 * re-used for any number of subsequent submissions.
 */
public interface QueryManager
{
	/**
	 * Returns the set of all Entities that satisfy the criteria expressed in
	 * the given EntityQuery.
   * <p>
	 * In the case where a null query is passed to the QueryManager, the QueryManager
   * is to return all Entities in the QueryManager.
   * @param query The query describing the {@link Entity} objects that pass.
	 * @return All the {@link Entity} objects that pass the query.
	 */
	Collection<Entity> submitEntityQuery( EntityQuery query );	
	
}
